@@ -52,7 +52,7 @@ plot.pedigree <- function(x, id = x$id, sex = x$sex, status = x$status,
 		stop("Wrong length for affected")
 
 	    if (is.logical(affected)) affected <- as.numeric(affected)
-	    if (is.factor(affected))  affected <- as.numeric(affected) -1
+	    if (is.factor(affected))  affected <- as.numeric(affected) - 1
 	    }
 	if(max(affected) > min(affected)) 
               affected <- matrix(affected - min(affected),nrow=n)
@@ -488,23 +488,22 @@ plot.pedigree <- function(x, id = x$id, sex = x$sex, status = x$status,
             twloc <- (1:length(tw.right))[tw.left]
             famloc <- (1:length(tw.right))[famlst==fam]
             flag <- NULL
-            for(i in twloc) flag <- c(flag,min(famloc[i<famloc]))
+            for(j in twloc) flag <- c(flag,min(famloc[j<famloc]))
             tw.right[flag] <- T
 
             mz.right <- rep(F,length(mz.left))
             mzloc <- (1:length(mz.right))[mz.left]
             flag <- NULL
-            for(i in mzloc) flag <- c(flag,min(famloc[i<famloc]))
+            for(j in mzloc) flag <- c(flag,min(famloc[j<famloc]))
             mz.right[flag] <- T
 
             ## unknown zygosity of the twin (type=3)
             un.right <- rep(F,length(un.left))
             unloc <- (1:length(un.right))[un.left]
             flag <- NULL
-            for(i in unloc) flag <- c(flag,min(famloc[i<famloc]))
+            for(j in unloc) flag <- c(flag,min(famloc[j<famloc]))
             un.right[flag] <- T
 
-
           }
             
             if(is.null(plist$twins)){
@@ -541,12 +540,12 @@ plot.pedigree <- function(x, id = x$id, sex = x$sex, status = x$status,
             #####################################################
             # draw diag line for twins
              ## left side of twin
-#	    segments(xx.l, yy.l + (1/adj) * radius, .5*(xx.l+xx.r), yy.l + 3 * delta, 
-#		     col = col[ww.l])
+	    segments(xx.l, yy.l + (1/adj) * radius, .5*(xx.l+xx.r), yy.l + 3 * delta, 
+		     col = col[ww.l])
 
              ## right side of twin
-#	    segments(xx.r, yy.r + (1/adj) * radius, .5*(xx.l+xx.r), yy.r + 3 * delta, 
-#		     col = col[ww.r])
+	    segments(xx.r, yy.r + (1/adj) * radius, .5*(xx.l+xx.r), yy.r + 3 * delta, 
+		     col = col[ww.r])
 
              ## draw midpoint MZ twin line
 
@@ -556,10 +555,10 @@ plot.pedigree <- function(x, id = x$id, sex = x$sex, status = x$status,
             xx.rm <- plist$pos[i, mz.right]
             yy.rm <- rep( - i, length = sum(mz.right))
 
-#            segments(.5*(xx.lm+.5*(xx.rm+xx.lm)),
-#                     .5*(yy.lm+(1/adj)*radius + yy.lm+3*delta),
-#                     .5*(xx.rm+.5*(xx.rm+xx.lm)),
-#                     .5*(yy.rm+(1/adj)*radius + yy.lm+3*delta))
+            segments(.5*(xx.lm+.5*(xx.rm+xx.lm)),
+                     .5*(yy.lm+(1/adj)*radius + yy.lm+3*delta),
+                     .5*(xx.rm+.5*(xx.rm+xx.lm)),
+                     .5*(yy.rm+(1/adj)*radius + yy.lm+3*delta))
             
              ## add question mark for unknown zygosity
 
